@@ -179,6 +179,7 @@ class EWAHBaseOperator(BaseOperator):
         pickling_upload_chunk_size=100000,  # default chunk size for pickle upload
         pickle_compression=None,  # data compression algorithm to use for pickles
         default_values=None,  # dict with default values for columns (to avoid nulls)
+        cast_bson_objects_to_string=True,  # how to serialize bson object ids
         *args,
         **kwargs
     ):
@@ -358,6 +359,7 @@ class EWAHBaseOperator(BaseOperator):
         self.pickling_upload_chunk_size = pickling_upload_chunk_size
         self.pickle_compression = pickle_compression
         self.default_values = default_values
+        self.cast_bson_objects_to_string = cast_bson_objects_to_string
 
         self.uploader = get_uploader(self.dwh_engine)
 
@@ -789,6 +791,7 @@ class EWAHBaseOperator(BaseOperator):
             hash_columns=self.hash_columns,
             hashlib_func_name=self.hashlib_func_name,
             default_values=self.default_values,
+            bson_to_string=self.cast_bson_objects_to_string,
         )
         """ Note on committing changes:
             The hook used for data uploading is created at the beginning of the
